@@ -184,7 +184,7 @@ static void sendXIDEnd(LAPPrivate* lapp)
 static void sendXIDResponse(LAPPrivate* lapp, int addr, int flags, int slot)
 {
   if(lapp->lap.debug&LAP_DEBUG_FRAMES_OUT) {
-    log("sendXIDResponse: lap-addr=%x addr=%x\n", lapp->address, addr);
+    birda_log("sendXIDResponse: lap-addr=%x addr=%x\n", lapp->address, addr);
   }
   lapp->ctrlBuf[0]=BROADCAST_HANDLE;
   lapp->ctrlBuf[1]=U_XID_RSP|PF_MASK;
@@ -360,7 +360,7 @@ static void sReply(LAPPrivate* lapp)
   lapp->ctrlBuf[1]|=lapp->mod&MOD_BUSY_LOCAL ? S_RNR : S_RR;
   fd->sendFrame(fd,lapp->ctrlBuf,2);
   if(lapp->lap.debug&LAP_DEBUG_FRAMES_OUT) {
-    log("sReply out: "); showBytes(lapp->ctrlBuf,2);
+    birda_log("sReply out: "); showBytes(lapp->ctrlBuf,2);
   }
 }
 
@@ -373,7 +373,7 @@ static void disconnectReply(LAPPrivate* lapp)
   lapp->ctrlBuf[1]=U_DISC|PF_MASK;
   fd->sendFrame(fd,lapp->ctrlBuf,2);
   if(lapp->lap.debug&LAP_DEBUG_FRAMES_OUT) {
-    log("disc out: "); showBytes(lapp->ctrlBuf,2);
+    birda_log("disc out: "); showBytes(lapp->ctrlBuf,2);
   }
 }
 
@@ -385,7 +385,7 @@ static void xidReplyTimer(void* lap)
 {
   LAPPrivate* lapp=(LAPPrivate*)lap;
 
-  if(lapp->lap.debug&LAP_DEBUG_TIMERS) log("xidReplyTimer\n");
+  if(lapp->lap.debug&LAP_DEBUG_TIMERS) birda_log("xidReplyTimer\n");
   lapp->state=STATE_NDM;
 }
 
@@ -393,9 +393,9 @@ static void speedChangeTimer(void* lap)
 {
   LAPPrivate* lapp=(LAPPrivate*)lap;
 
-  if(lapp->lap.debug&LAP_DEBUG_TIMERS) log("speedChangeTimer %d\n",lapp->sendParams.speed);
+  if(lapp->lap.debug&LAP_DEBUG_TIMERS) birda_log("speedChangeTimer %d\n",lapp->sendParams.speed);
   lapp->fdev->setParams(lapp->fdev,lapp->sendParams.speed,lapp->sendParams.extraBOFs,RECV_DATASIZE+2);
-  if(lapp->lap.debug&LAP_DEBUG_INFO) log("%d baud\n",lapp->sendParams.speed);
+  if(lapp->lap.debug&LAP_DEBUG_INFO) birda_log("%d baud\n",lapp->sendParams.speed);
 }
 
 static void disconnectTimer(void* lap)
@@ -410,7 +410,7 @@ static void receiveTimer(void* lap)
   LAPPrivate* lapp=(LAPPrivate*)lap;
   int delay=lapp->state==STATE_PRIMARY ? PRIMARY_TIMEOUT : SECONDARY_TIMEOUT;
 
-  if(lapp->lap.debug&LAP_DEBUG_TIMERS) log("receiveTimer\n");
+  if(lapp->lap.debug&LAP_DEBUG_TIMERS) birda_log("receiveTimer\n");
   if(++lapp->nTimeouts*delay>=lapp->sendParams.disconnect*1000) {
     disconnectLAP(lapp);
   } else {
@@ -429,7 +429,7 @@ static void turnaroundTimer(void* lap)
   int queryEnd=0;
 
   fd=lapp->fdev;
-  if(lapp->lap.debug&LAP_DEBUG_TIMERS) log("turnaroundTimer\n");
+  if(lapp->lap.debug&LAP_DEBUG_TIMERS) birda_log("turnaroundTimer\n");
 
   if(lapp->state==STATE_QUERY) {
     if(lapp->xidSlot<answerSlots[lapp->xidFlags&XID_SLOTS_MASK]) {
@@ -455,7 +455,7 @@ static void turnaroundTimer(void* lap)
   if(lapp->mod&MOD_CONTROL) {
     fd->sendFrame(fd,lapp->ctrlBuf,lapp->ctrlLen);
     if(lapp->lap.debug&LAP_DEBUG_FRAMES_OUT) {
-      log("turn1 out: "); showBytes(lapp->ctrlBuf,lapp->ctrlLen);
+      birda_log("turn1 out: "); showBytes(lapp->ctrlBuf,lapp->ctrlLen);
     }
   } else {
     int answered=0;
@@ -479,7 +479,7 @@ static void turnaroundTimer(void* lap)
 
 	fd->sendFrame(fd,sb->buf,sb->length);
 	if(lapp->lap.debug&LAP_DEBUG_FRAMES_OUT) {
-	  log("turn2 out: "); showBytes(sb->buf,sb->length);
+	  birda_log("turn2 out: "); showBytes(sb->buf,sb->length);
 	}
 	sb=sb->next;
       }
@@ -621,13 +621,13 @@ static bool readParams(LAPPrivate* lapp, const u_char* buf, int len, Params* par
   params->disconnect=disconnectBits[highestBit(bits)];
 
 #if 0
-  log("adjust window and data sizes is NYI\n");
+  birda_log("adjust window and data sizes is NYI\n");
   /* NB: Don't truncate the window size, turnaroundTimer should
    *     instead estimate the time needed based on actual frame
    *     sizes, and queue up as many as possible within the
    *     allowed window size
    */
-  log("params: speed=%d maxta=%d data=%d window=%d bofs=%d minta=%d disc=%d\n",
+  birda_log("params: speed=%d maxta=%d data=%d window=%d bofs=%d minta=%d disc=%d\n",
 	 lapp->speed,lapp->maxTurnaround,lapp->dataSize,lapp->windowSize,
 	 lapp->extraBOFs,lapp->minTurnaround,lapp->disconnect);
 #endif
@@ -692,7 +692,7 @@ static void connectUA(LAPPrivate* lapp, Params* params)
 			      lapp->sendParams.extraBOFs,RECV_DATASIZE+2);
   lapp->state=STATE_PRIMARY;
   sendFirstRR(lapp);
-  if(lapp->lap.debug&LAP_DEBUG_INFO) log("%d baud\n",lapp->sendParams.speed);
+  if(lapp->lap.debug&LAP_DEBUG_INFO) birda_log("%d baud\n",lapp->sendParams.speed);
 
   /* Wait at least 10ms for the speed change to take effect */
   if(delay<10) delay=10;
@@ -705,10 +705,10 @@ static void snoopResetSpeed(void* lap)
 {
   LAPPrivate* lapp=(LAPPrivate*)lap;
 
-  log("snoopResetSpeed\n");
+  birda_log("snoopResetSpeed\n");
   lapp->sendParams.speed=9600;
   lapp->fdev->resetParams(lapp->fdev);
-  log("reset\n");
+  birda_log("reset\n");
 }
 #endif
 
@@ -717,9 +717,9 @@ static void snoopFollowSpeed(LAPPrivate* lapp, const u_char* buf, int len)
   /* XXX why > 10? in my case the size is exactly 10 */
   if(len>10 && buf[1]==(U_UA|PF_MASK)) {
     if(readParams(lapp,buf+10,len-10,&lapp->sendParams)) {
-      log("snoopFollowSpeed %d\n",lapp->sendParams.speed);
+      birda_log("snoopFollowSpeed %d\n",lapp->sendParams.speed);
       lapp->fdev->setParams(lapp->fdev,lapp->sendParams.speed,0,RECV_DATASIZE+2);
-      log("%d baud\n",lapp->sendParams.speed);
+      birda_log("%d baud\n",lapp->sendParams.speed);
     }
   }
 }
@@ -734,7 +734,7 @@ static void frame(FrameDevice* fd, void* buf0, int len)
   u_char isFinal=(PF_MASK&buf[1])!=0;
 
   if(lapp->lap.debug&LAP_DEBUG_FRAMES_IN) {
-    log("in: "); showBytes(buf,len);
+    birda_log("in: "); showBytes(buf,len);
   }
   if(lapp->lap.debug&LAP_SNOOP) {
     snoopFollowSpeed(lapp,buf,len);
@@ -857,7 +857,7 @@ static void frame(FrameDevice* fd, void* buf0, int len)
   } else if(lapp->state==STATE_PRIMARY || lapp->state==STATE_SECONDARY) {
     if(handle!=lapp->handle) return;
     if((lapp->state==STATE_PRIMARY) == isCommand) {
-      log("Primary/secondary conflict\n");
+      birda_log("Primary/secondary conflict\n");
       disconnectLAP(lapp);
       return;
     }
@@ -872,7 +872,7 @@ static void frame(FrameDevice* fd, void* buf0, int len)
       }
 
       if(!lapp->sendHead && nr!=lapp->nextVs) {
-	log("Sequence error (nr)\n");
+	birda_log("Sequence error (nr)\n");
       }
 
       if(IS_S(control)) {
@@ -911,7 +911,7 @@ static void resetState(LAPPrivate* lapp)
   lapp->mod=0;
   lapp->sendParams.minTurnaround=0;
   fd->resetParams(fd);
-  if(lapp->lap.debug&LAP_DEBUG_INFO) log("reset\n");
+  if(lapp->lap.debug&LAP_DEBUG_INFO) birda_log("reset\n");
 }
 
 static void disconnectLAP(LAPPrivate* lapp)
