@@ -211,7 +211,7 @@ static void serialSetSpeed(SerialPort* sp, int speed) {
   int speedcode;
 
   if(tcgetattr(usp->fd,&t)) {
-    log("tcgetattr failed\n");
+    birda_log("tcgetattr failed\n");
     return;
   }
   switch(speed) {
@@ -222,13 +222,13 @@ static void serialSetSpeed(SerialPort* sp, int speed) {
   case 9600:   speedcode=B9600;   break;
   case 2400:   speedcode=B2400;   break;
   default:
-    log("unsupported speed\n");    
+    birda_log("unsupported speed\n");    
     return;
   }
   cfsetispeed(&t,speedcode);
   cfsetospeed(&t,speedcode);
   if(tcsetattr(usp->fd,TCSADRAIN,&t)) {
-    log("tcsetattr failed\n");
+    birda_log("tcsetattr failed\n");
   }
 }
 
@@ -237,7 +237,7 @@ static void serialSetLine(SerialPort* sp, int line) {
   int flags;
 
   if(ioctl(usp->fd,TIOCMGET,&flags)==-1) {
-    log("ioctl failed %d\n", __LINE__);
+    birda_log("ioctl failed %d\n", __LINE__);
   }
 
   flags&=~(TIOCM_DTR|TIOCM_RTS);
@@ -245,7 +245,7 @@ static void serialSetLine(SerialPort* sp, int line) {
   if(line&LINE_RTS) flags|=TIOCM_RTS;
 
   if(ioctl(usp->fd,TIOCMSET,&flags)==-1) {
-    log("ioctl failed %d\n", __LINE__);
+    birda_log("ioctl failed %d\n", __LINE__);
   }
 }
 
@@ -265,7 +265,7 @@ static void serialInput(void* sp)
     sizeof usp->inBuf-usp->inFree : usp->inHead-usp->inFree-1;
   int n=read(usp->fd,usp->inBuf+usp->inFree,k);
 
-  if(usp->serial.debug&SP_DEBUG_INPUT) log("serial port read %d bytes\n",n);
+  if(usp->serial.debug&SP_DEBUG_INPUT) birda_log("serial port read %d bytes\n",n);
   if(n<=0) return;
   empty=usp->inHead==usp->inFree;
   usp->inFree=(usp->inFree+n)%sizeof usp->inBuf;
@@ -312,7 +312,7 @@ static void flush(UNIXSerialPort* usp)
 static void serialOutput(void* sp)
 {
   UNIXSerialPort* usp=(UNIXSerialPort*)sp;
-  if(evtDebug&EVT_DEBUG_TIMERS) log("serialOutput\n");
+  if(evtDebug&EVT_DEBUG_TIMERS) birda_log("serialOutput\n");
   if(usp->outFree>0) flush(usp);
 }
 
@@ -340,7 +340,7 @@ static void serialClose(SerialPort* sp)
     }
   }
   if(!u) {
-    log("ERROR: closing unallocated UNIX serial port\n");
+    birda_log("ERROR: closing unallocated UNIX serial port\n");
     return;
   }
 
@@ -367,7 +367,7 @@ void setSysLog(void)
   sysLog=TRUE;
 }
 
-void log(const char* fmt, ...)
+void birda_log(const char* fmt, ...)
 {
   va_list ap;
 
@@ -388,7 +388,7 @@ void* allocMem(const char* id, int size)
   Memory* m=malloc(sizeof(Memory));
 
   if(!ptr || !m) {
-    log("PANIC: malloc failed\n");
+    birda_log("PANIC: malloc failed\n");
     return 0;
   }
 
@@ -408,13 +408,13 @@ void* growMem(void* ptr, int size)
 
   while(m && m->ptr!=ptr) m=m->next;
   if(!m) {
-    log("ERROR: growing unallocated memory\n");
+    birda_log("ERROR: growing unallocated memory\n");
     return 0;
   }
 
   nptr=realloc(ptr,size);
   if(!nptr) {
-    log("PANIC: realloc failed\n");
+    birda_log("PANIC: realloc failed\n");
     return 0;
   }
 
@@ -439,7 +439,7 @@ void freeMem(void *ptr)
       mh=&m->next;
     }
   }
-  log("ERROR: freeing unallocated memory\n");
+  birda_log("ERROR: freeing unallocated memory\n");
 }
 
 void showResources(void)
@@ -450,25 +450,25 @@ void showResources(void)
   Timer* t;
   Memory* m;
 
-  log("-----------------\n");
+  birda_log("-----------------\n");
 
   for(n=0,u=ports;u;u=u->next) n++;
-  log("%d unixSerialPorts\n",n);
+  birda_log("%d unixSerialPorts\n",n);
 
   for(n=0,s=sources;s;s=s->next) if(s->func!=serialInput) n++;
-  log("%d other sources\n",n);
+  birda_log("%d other sources\n",n);
 
   for(n=0,t=timers;t;t=t->next) n++;
-  log("%d timers\n",n);
+  birda_log("%d timers\n",n);
 
-  log("Memory:\n");
+  birda_log("Memory:\n");
   for(n=0,b=0,m=allocs;m;m=m->next) {
-    log("  addr=%p size=%5d id=%s\n",m->ptr,m->size,m->id);
+    birda_log("  addr=%p size=%5d id=%s\n",m->ptr,m->size,m->id);
     n++;
     b+=m->size;
   }
-  log("  total: %d blocks, %d bytes\n",n,b);
-  log("-----------------\n");
+  birda_log("  total: %d blocks, %d bytes\n",n,b);
+  birda_log("-----------------\n");
 }
 
 unsigned getRandom(unsigned max)
@@ -587,9 +587,9 @@ void evtLoop(void)
 	Timer* ti=timers;
 	timers=ti->next;
 	if(evtDebug&EVT_DEBUG_TIMERS)
-	  log("timer called %p %p\n",ti->func,ti->handle);
+	  birda_log("timer called %p %p\n",ti->func,ti->handle);
 	ti->func(ti->handle);
-	if(evtDebug&EVT_DEBUG_TIMERS) log("timer completed\n");
+	if(evtDebug&EVT_DEBUG_TIMERS) birda_log("timer completed\n");
 	free(ti);
 	continue;
       }
@@ -603,13 +603,13 @@ void evtLoop(void)
     }
 
     if(evtDebug&EVT_DEBUG_SELECT)
-      log("select %s timers\n",timers ? "with" : "without");
+      birda_log("select %s timers\n",timers ? "with" : "without");
 
     if(select(fdmax,&fds,0,0,timers ? &t : 0)==-1 && errno!=EINTR)
       perror("select");
 
     if(evtDebug&EVT_DEBUG_SELECT)
-      log("wakeup\n");
+      birda_log("wakeup\n");
 
     for(s=sources;s && !FD_ISSET(s->fd,&fds);s=s->next);
     if(s) s->func(s->handle);
@@ -639,7 +639,7 @@ static int kfd_setParams(FrameDevice* fd, int baud, int ebofs, int maxSize)
   params.maxsize = maxSize;
 
   if (ioctl(kfd->fdesc, IRDA_SET_PARAMS, &params) == -1) {
-    log("ioctl failed %d\n", __LINE__);
+    birda_log("ioctl failed %d\n", __LINE__);
   }
 
   if(kfd->maxSize != maxSize) {
@@ -657,7 +657,7 @@ static void kfd_resetParams(FrameDevice* fd)
   KernelFrameDevice* kfd = (KernelFrameDevice*)fd;
 
   if (ioctl(kfd->fdesc, IRDA_RESET_PARAMS) == -1) {
-    log("ioctl failed %d\n", __LINE__);
+    birda_log("ioctl failed %d\n", __LINE__);
   }
 }
 
@@ -679,7 +679,7 @@ static int kfd_getSpeedMask(FrameDevice* fd)
   int speedmask;
 
   if (ioctl(kfd->fdesc, IRDA_GET_SPEEDMASK, &speedmask) == -1) {
-    log("ioctl failed %d\n", __LINE__);
+    birda_log("ioctl failed %d\n", __LINE__);
   }
   
   if(maxspeed>0) {
@@ -702,7 +702,7 @@ static int kfd_getMinTurnaroundMask(FrameDevice* fd)
   int tamask;
 
   if (ioctl(kfd->fdesc, IRDA_GET_TURNAROUNDMASK, &tamask) == -1) {
-    log("ioctl failed %d\n", __LINE__);
+    birda_log("ioctl failed %d\n", __LINE__);
   }
 
   return tamask;
@@ -735,7 +735,7 @@ FrameDevice* createKernelFrameDevice(char *dev, int maxspeed)
 
   if ((kfd->fdesc = open(kfd->devname, O_RDWR|O_NONBLOCK)) < 0) {
     freeMem(kfd);
-    log("Cannot open port %s\n", dev);
+    birda_log("Cannot open port %s\n", dev);
     exit(-16);
   }
   
